Package: curatedPCaData
Title: Curated Prostate Cancer Data
Version: 1.8.0
Date: 2024-01-10
Authors@R: c(person("Teemu Daniel", "Laajala", email = "teelaa@utu.fi", 
        role = c("aut", "cre"), comment = c(ORCID = "0000-0002-7016-7354")),
    person("Jordan", "Creed", email = "jordan.h.creed@moffitt.org", 
		role = "ctb"),
    person("Christelle", "Colin Leitzinger", email = 
	    "christelle.colinleitzinger@moffitt.org", role = "ctb"),
    person("Varsha", "Sreekanth", email = "varsha.sreekanth@cuanschutz.edu", 
	    role = "ctb"), 
    person("Federico", "Calboli", email = "federico.calboli@luke.fi", 
	    role = "ctb"),
    person("Kalaimathy", "Singaravelu", email = "kalsin@utu.fi", role = "ctb"),
    person("Michael", "Orman", email = "michael.orman@cuanschutz.edu", 
	    role = "ctb"),
    person("Alex", "Soupir", email = "Alex.Soupir@moffitt.org", role = "ctb"),
    person("Anni", "Halkola", email = "ansuha@utu.fi", role = "ctb"))
Description: The package curatedPCaData offers a selection of annotated prostate
 cancer datasets featuring multiple omics, manually curated metadata, and 
 derived downstream variables. The studies are offered as MultiAssayExperiment 
 (MAE) objects via ExperimentHub, and comprise of clinical characteristics tied 
 to gene expression, copy number alteration and somatic mutation data. Further, 
 downstream features computed from these multi-omics data are offered. Multiple 
 vignettes help grasp characteristics of the various studies and provide example
 exploratory and meta-analysis of leveraging the multiple studies provided 
 here-in.
License: CC BY 4.0
Encoding: UTF-8
RoxygenNote: 7.2.3
VignetteBuilder: knitr
biocViews: ExperimentHub, ExperimentData, ProstateCancerData,
        CancerData, Homo_sapiens_Data, MicroarrayData, RNASeqData,
        ExpressionData, CopyNumberVariationData, Somatic, GEO,
        ReproducibleResearch
URL: https://github.com/Syksy/curatedPCaData
BugReports: https://github.com/Syksy/curatedPCaData/issues
Depends: R (>= 4.4.0), S4Vectors (>= 0.23.18), MultiAssayExperiment,
        RaggedExperiment
Imports: ExperimentHub, AnnotationHub, utils, methods, rlang, stats,
        reshape2
Suggests: BiocStyle, knitr, ggplot2, rmarkdown, survival, survminer,
        ComplexHeatmap, corrplot, formatR
git_url: https://git.bioconductor.org/packages/curatedPCaData
git_branch: RELEASE_3_23
git_last_commit: 060f061
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 15:19:15 UTC; biocbuild
Author: Teemu Daniel Laajala [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7016-7354>),
  Jordan Creed [ctb],
  Christelle Colin Leitzinger [ctb],
  Varsha Sreekanth [ctb],
  Federico Calboli [ctb],
  Kalaimathy Singaravelu [ctb],
  Michael Orman [ctb],
  Alex Soupir [ctb],
  Anni Halkola [ctb]
Maintainer: Teemu Daniel Laajala <teelaa@utu.fi>
