% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{curatedPCaDatasets_baca}
\alias{curatedPCaDatasets_baca}
\title{Baca et al. MAE-object}
\format{
A MAE object spanning 56 prostate cancer samples.
\describe{
    \item{cna.gistic}{matrix with 20124 rows and 56 columns, from GISTIC 
        discretized copy number alteration calls.}
    \item{mut}{RaggedExperiment with 2734 rows and 57 columns, mutation data 
        from cbioportal}
}
}
\source{
\url{https://www.cbioportal.org/study/summary?id=prad_broad_2013}
}
\value{
A MultiAssayExperiment corresponding to the study and its available 
omics.
}
\description{
MultiAssayExperiment object containing copy number alteration (cna) and 
mutations for Baca et al.
}
\examples{
mae_baca <- getPCa('baca')
}
\keyword{datasets}
